@@ -14,8 +14,12 @@ def _is_valid_ip(addr, _class: typing.Any = ipaddress.IPv4Network):
         return False
 
 
-def is_valid_ip(addr):
-    return _is_valid_ip(addr) or _is_valid_ip(addr, _class=ipaddress.IPv6Network)
+def is_valid_ipv4(addr):
+    return _is_valid_ip(addr)
+
+
+def is_valid_ipv6(addr):
+    return _is_valid_ip(addr, _class=ipaddress.IPv6Network)
 
 
 def _append_port(addr: str, port: typing.Optional[int]):
@@ -28,7 +32,7 @@ def _resolve_dns(server: str) -> typing.List[str]:
         result = urlsplit('//' + server)
         addr = result.hostname
         port = result.port
-        if is_valid_ip(addr):
+        if is_valid_ipv4(addr):  # memcached supports only IPv4
             return [_append_port(addr, port)]
         _, _, ips = socket.gethostbyname_ex(addr)
         return [_append_port(ip, port) for ip in ips]
